//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Device/Data/ArrayUtils.h
//! @brief     Defines various functions to interact from numpy on Python side
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifdef SWIG
#error no need to expose this header to Swig
#endif

#ifndef USER_API
#ifndef BORNAGAIN_DEVICE_DATA_ARRAYUTILS_H
#define BORNAGAIN_DEVICE_DATA_ARRAYUTILS_H

#include "Device/Data/Powerfield.h"
#include <memory>
#include <vector>

//! Array utility functions getShape

namespace DataUtils::Array {

//! Returns shape nrows, ncols of 2D array.
std::pair<size_t, size_t> getShape(const std::vector<std::vector<double>>& data);

std::unique_ptr<Powerfield<double>> createData(const std::vector<double>& vec);

std::unique_ptr<Powerfield<double>> createData(const std::vector<std::vector<double>>& vec);

//! Creates 1D vector from Powerfield.
std::vector<double> createVector1D(const Powerfield<double>& data);

//! Creates 2D vector from Powerfield.
std::vector<std::vector<double>> createVector2D(const Powerfield<double>& data);

} // namespace DataUtils::Array

#endif // BORNAGAIN_DEVICE_DATA_ARRAYUTILS_H
#endif // USER_API
