## BornAgain developer reference {#mainpage}

C++ developer reference of the BornAgain GUI.
<a href="http://www.bornagainproject.org">BornAgain</a> is
 an open-source software to simulate and fit
 neutron and x-ray reflectometry and grazing-incidence small-angle scattering.

### See also

* <https://bornagainproject.org>, project homepage;
* <https://github.com/scgmlz/BornAgain>, source repository;

### License

[GNU General Public License v3 or higher](https://github.com/scgmlz/BornAgain/blob/master/COPYING)

Copyright Forschungszentrum Jülich GmbH 2015-


### Authors

Scientific Computing Group at MLZ Garching.

See file [AUTHORS](https://github.com/scgmlz/BornAgain/blob/master/AUTHORS).

### Citation

See file [CITATION](https://github.com/scgmlz/BornAgain/blob/master/CITATION).


### Classes for representing the UI data

For representing the UI data there are classes which provide
* storing the value
* serializing the value
* accessing the value
* additional properties like label, tooltip, unit, limits
* creating a UI element for this value

The most important classes regarding data representation are

Class                     | Description
--------------------------|------------
@ref DoubleProperty       | @copybrief DoubleProperty
@ref UIntProperty         | @copybrief UIntProperty
@ref VectorProperty       | @copybrief VectorProperty
@ref SelectionProperty    | @copybrief SelectionProperty
@ref AxisProperty         | @copybrief AxisProperty

as well as their direct associates

Class                     | Description
--------------------------|------------
@ref DoubleDescriptor     | @copybrief DoubleDescriptor
@ref UIntDescriptor       | @copybrief UIntDescriptor
@ref VectorDescriptor     | @copybrief VectorDescriptor
@ref SelectionDescriptor  | @copybrief SelectionDescriptor


### Migration to eliminate SessionModel/SessionItem

The descriptions in the following issues contain detailed explanations and best-practices how to eliminate SessionModel and SessionItem dependency:

[Refactor signaling of value changes (less generic, more explicit)](https://jugit.fz-juelich.de/mlz/bornagain/-/issues/88)

[Refactor dynamic hierarchy in SessionItems (less generic, more explicit)](https://jugit.fz-juelich.de/mlz/bornagain/-/issues/89)

[Refactor serialization of SessionItem (less generic, more explicit)](https://jugit.fz-juelich.de/mlz/bornagain/-/issues/90)

Also mentioned should be the explanations in [merge request 695](https://jugit.fz-juelich.de/mlz/bornagain/-/merge_requests/695). In 
this merge request the UI-code was greatly simplified by using descriptors and related functions like GUI::Util::createSpinBox().

