//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Device/Instrument.h
//! @brief     Defines class Instrument.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef USER_API
#ifndef BORNAGAIN_GUI_MODEL_DEVICE_INSTRUMENT_H
#define BORNAGAIN_GUI_MODEL_DEVICE_INSTRUMENT_H

#include <memory>

class Beam;
class IDetector2D;

//! Assembles beam, detector and their relative positions with respect to the sample.

class Instrument {
public:
    Instrument(const Beam& beam, const IDetector2D& detector);
    ~Instrument();

    const Beam& beam() const { return *m_beam; }
    const IDetector2D& detector() const { return *m_detector; }

protected:
    std::unique_ptr<Beam> m_beam;
    std::unique_ptr<IDetector2D> m_detector;
};

#endif // BORNAGAIN_GUI_MODEL_DEVICE_INSTRUMENT_H
#endif // USER_API
