//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Device/InstrumentsEditController.cpp
//! @brief     Implements class InstrumentsEditController
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/Model/Device/InstrumentsEditController.h"
#include "GUI/Model/Device/InstrumentItems.h"

InstrumentsEditController::InstrumentsEditController(InstrumentCollection* instruments)
    : m_instruments(instruments)
{
}

InstrumentCollection* InstrumentsEditController::collectedItems()
{
    return m_instruments;
}

void InstrumentsEditController::removeInstrument(InstrumentItem* instrument)
{
    m_instruments->removeInstrument(instrument);
    emit instrumentAddedOrRemoved();
}

InstrumentItem* InstrumentsEditController::addCopy(const InstrumentItem* instrument,
                                                   const QString& name)
{
    InstrumentItem* copy = m_instruments->insertCopy(*instrument);
    copy->setInstrumentName(name);
    emit instrumentAddedOrRemoved();
    return copy;
}

void InstrumentsEditController::setInstrumentName(InstrumentItem* instrument, const QString& name)
{
    if (instrument->instrumentName() != name) {
        instrument->setInstrumentName(name);
        emit instrumentNameChanged(instrument);
        emit instrumentChanged(instrument);
    }
}

void InstrumentsEditController::updateInstrumentToRealDataItem(InstrumentItem* instrument,
                                                               const RealDataItem* realDataItem)
{
    instrument->updateToRealData(realDataItem);
    emit instrumentChanged(instrument);
}

void InstrumentsEditController::notifyInstrumentChanged(InstrumentItem* instrument)
{
    emit instrumentChanged(instrument);
}
