//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Resample/Particle/ReCoreShell.cpp
//! @brief     Implements class ReCoreShell.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "Resample/Particle/ReCoreShell.h"
#include "Base/Spin/SpinMatrix.h"
#include "Base/Vector/WavevectorInfo.h" // debug

ReCoreShell::ReCoreShell(IReParticle* core, IReParticle* shell)
    : m_core(core)
    , m_shell(shell)
{
}

ReCoreShell::~ReCoreShell() = default;

ReCoreShell* ReCoreShell::clone() const
{
    return new ReCoreShell(m_core->clone(), m_shell->clone());
}

double ReCoreShell::radialExtension() const
{
    return m_shell->radialExtension();
}

double ReCoreShell::bottomZ(const IRotation* rotation) const
{
    return m_shell->bottomZ(rotation);
}

double ReCoreShell::topZ(const IRotation* rotation) const
{
    return m_shell->topZ(rotation);
}

void ReCoreShell::setAmbientMaterial(const Material& material)
{
    m_shell->setAmbientMaterial(material);
}

complex_t ReCoreShell::theFF(const WavevectorInfo& wavevectors) const
{
    return m_shell->theFF(wavevectors) + m_core->theFF(wavevectors);
}

SpinMatrix ReCoreShell::thePolFF(const WavevectorInfo& wavevectors) const
{
    return m_shell->thePolFF(wavevectors) + m_core->thePolFF(wavevectors);
}
