//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Sample/HardParticle/Bipyramid4.h
//! @brief     Defines class Bipyramid4
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_SAMPLE_HARDPARTICLE_BIPYRAMID4_H
#define BORNAGAIN_SAMPLE_HARDPARTICLE_BIPYRAMID4_H

#include "Sample/HardParticle/IFormFactorPolyhedron.h"

//! A truncated bifrustum with quadratic base.
//! @ingroup hardParticle

class Bipyramid4 : public IFormFactorPolyhedron {
public:
    Bipyramid4(double length, double height, double height_ratio, double alpha);
#ifndef USER_API
    Bipyramid4(std::vector<double> P);
    Bipyramid4* clone() const override
    {
        return new Bipyramid4(m_length, m_height, m_height_ratio, m_alpha);
    }
    std::string className() const final { return "Bipyramid4"; }
    // const auto tooltip = "truncated quadratic bipyramid";
    std::vector<ParaMeta> parDefs() const final
    {
        return {{"Length", "nm", "edge length of base square (common face of both pyramids)", 0,
                 +INF, 0},
                {"Height", "nm", "height of the lower pyramid", 0, +INF, 0},
                {"HeightRatio", "", "height ratio of upper to lower pyramid", 0, +INF, 0},
                {"Alpha", "rad", "angle between the base and a side face", 0., M_PI_2, 0}};
    }
    double length() const { return m_length; }
    double height() const { return m_height; }
    double heightRatio() const { return m_height_ratio; }
    double alpha() const { return m_alpha; }
#endif // USER_API

private:
    static const ff::PolyhedralTopology topology;

    const double& m_length;
    const double& m_height;
    const double& m_height_ratio;
    const double& m_alpha;
};

#endif // BORNAGAIN_SAMPLE_HARDPARTICLE_BIPYRAMID4_H
