//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Sample/HardParticle/Pyramid2.h
//! @brief     Defines class Pyramid2
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_SAMPLE_HARDPARTICLE_PYRAMID2_H
#define BORNAGAIN_SAMPLE_HARDPARTICLE_PYRAMID2_H

#include "Sample/HardParticle/IFormFactorPolyhedron.h"

//! A frustum (truncated pyramid) with rectangular base.
//! @ingroup hardParticle

class Pyramid2 : public IFormFactorPolyhedron {
public:
    Pyramid2(double length, double width, double height, double alpha);
#ifndef USER_API
    Pyramid2(std::vector<double> P);

    Pyramid2* clone() const override { return new Pyramid2(m_length, m_width, m_height, m_alpha); }
    std::string className() const final { return "Pyramid2"; }
    // const auto tooltip = "frustum with rectangular base";
    std::vector<ParaMeta> parDefs() const final
    {
        return {{"Length", "nm", "side length of base in x direction", 0, +INF, 0},
                {"Width", "nm", "side length of base in y direction", 0, +INF, 0},
                {"Height", "nm", "height", 0, +INF, 0},
                {"Alpha", "rad", "angle between base and any side face", 0., M_PI_2, 0}};
    }

    double length() const { return m_length; }
    double width() const { return m_width; }
    double height() const { return m_height; }
    double alpha() const { return m_alpha; }

private:
    static const ff::PolyhedralTopology topology;

    const double& m_length;
    const double& m_width;
    const double& m_height;
    const double& m_alpha;
#endif // USER_API
};

#endif // BORNAGAIN_SAMPLE_HARDPARTICLE_PYRAMID2_H
