#include "Device/Data/Powerfield.h"
#include "Tests/GTestWrapper/google_test.h"

class PowerfieldIteratorTest : public ::testing::Test {
protected:
    PowerfieldIteratorTest();

    Powerfield<double> _data{FixedBinAxis("x", 3, 0, 1), FixedBinAxis("y", 5, 0, 1)};
};

PowerfieldIteratorTest::PowerfieldIteratorTest()
{
    _data.setRawDataVector({1., 2., 3., 4., 5., 11., 12., 13., 14., 15., 21., 22., 23., 24., 25.});
}

TEST_F(PowerfieldIteratorTest, Iterate)
{
    Powerfield<double>::iterator it = _data.begin();
    EXPECT_EQ(1.0, *it);
    for (size_t i = 0; i < 14; ++i) {
        ++it;
    }
    EXPECT_DOUBLE_EQ(25.0, *it);
    ++it;
    EXPECT_EQ(it, _data.end());
    ++it;
    EXPECT_EQ(it, _data.end());
}

TEST_F(PowerfieldIteratorTest, ConstIterate)
{
    Powerfield<double>::const_iterator it = _data.begin();
    EXPECT_EQ(1.0, *it);
    for (size_t i = 0; i < 14; ++i) {
        ++it;
    }
    EXPECT_DOUBLE_EQ(25.0, *it);
    ++it;
    EXPECT_EQ(it, _data.end());
    ++it;
    EXPECT_EQ(it, _data.end());
}
