#include "GUI/Model/Data/JobItemUtils.h"
#include "GUI/Model/Data/RealDataItem.h"
#include "GUI/Model/Device/AxesItems.h"
#include "GUI/Model/Device/InstrumentItems.h"
#include "GUI/Model/Device/RectangularDetectorItem.h"
#include "GUI/Model/Model/RealDataModel.h"
#include "GUI/Model/Project/LinkInstrumentManager.h"
#include "GUI/Model/Project/ProjectDocument.h"
#include "Tests/GTestWrapper/google_test.h"
#include "Tests/Unit/GUI/Utils.h"
#include <QSignalSpy>
#include <QTest>

class TestLinkInstrument : public ::testing::Test {
};

QList<RealDataItem*> linkedRealDataItems(RealDataModel& realDataModel,
                                         const InstrumentItem* instrumentItem)
{
    ASSERT(instrumentItem);

    QList<RealDataItem*> result;
    for (auto* realDataItem : realDataModel.realDataItems()) {
        const QString linkedIdentifier = realDataItem->instrumentId();
        const QString instrumentIdentifier = instrumentItem->id();

        if (linkedIdentifier == instrumentIdentifier)
            result.append(realDataItem);
    }
    return result;
}

TEST_F(TestLinkInstrument, canLinkToInstrument)
{
    ProjectDocument document;

    // populating instrument model
    auto* instrument = document.collectedItems()->addInstrument<GISASInstrumentItem>();
    const QString identifier = instrument->id();
    ASSERT_TRUE(!identifier.isEmpty());

    // populating real data model, setting intensity data
    RealDataItem* realData = UTest::GUI::createRealData("RealData", *document.realDataModel());
    GUI::Model::JobItemUtils::createDefaultDetectorMap(realData->dataItem(), instrument);

    ASSERT_TRUE(
        document.linkInstrumentManager()->canLinkDataToInstrument(realData, identifier, nullptr));

    // making link
    realData->linkToInstrument(instrument);
    EXPECT_EQ(linkedRealDataItems(*document.realDataModel(), instrument), QList<RealDataItem*>()
                                                                              << realData);

    // changing detector type and checking that link remain
    instrument->setDetectorType<RectangularDetectorItem>();
    EXPECT_EQ(linkedRealDataItems(*document.realDataModel(), instrument), QList<RealDataItem*>()
                                                                              << realData);

    // changing detector binning and checking that link is destroyed
    auto* detectorItem = dynamic_cast<RectangularDetectorItem*>(instrument->detectorItem());
    detectorItem->setXSize(10);
    document.instrumentsEditController()->notifyInstrumentChanged(instrument);

    EXPECT_EQ(linkedRealDataItems(*document.realDataModel(), instrument), QList<RealDataItem*>());
    EXPECT_EQ(realData->instrumentId(), QString());
}
